# -*- coding: utf-8 -*-

import os
import codecs

from docutils.core import publish_parts
from flask import Flask
from flask import render_template
from flask import request
from flask.ext.babel import gettext as _
from flask.ext.babel import Babel
from config import LANGUAGES

LANGUAGE_SELECTED = "de"
#ToDo after engelish is implemented set LANGUAGE_SELECTED = None

# We need the path of this file to find templates to translate
ESKP_PATH = os.path.dirname(os.path.abspath(__file__))

app = Flask(__name__)
babel = Babel(app)

app.config['BABEL_DEFAULT_LOCALE'] = 'de'


def get_content(filename, overrides=None):
    content = u""
    filename = os.path.join(ESKP_PATH, filename)
    if os.path.isfile(filename):
        with codecs.open(filename, 'r', 'utf-8') as f:
            rst_data = f.read()
        f.close()
        content = publish_parts(rst_data, writer_name='html', settings_overrides=overrides)['html_body']
    return content

def get_topmenue():
    menue = [
             ('/', _(u'Home')),
             ('/ozoneloss', _(u'Ozoneloss')),
             ('/eskp', _(u'ESKP')),
             ('/iek-7', _(u'IEK-7')),
            ]
    return menue

app.jinja_env.globals.update(get_topmenue=get_topmenue)

def get_o3lossclams_dates():
    menue = [('/ozoneloss/clams/2012', _(u'2012')),
             ('/ozoneloss/clams/2011', _(u'2011')),
             ('/ozoneloss/clams/2010', _(u'2010')),
             ]
    return menue

def get_vpsc_dates():
    menue = [('/ozoneloss/vpsc/2014', _(u'2014')),
             ('/ozoneloss/vpsc/2013', _(u'2013')),
             ('/ozoneloss/vpsc/2012', _(u'2012')),
             ('/ozoneloss/vpsc/2011', _(u'2011')),
             ('/ozoneloss/vpsc/2010', _(u'2010')),
             ]
    return menue

app.jinja_env.globals.update(get_o3lossclams_dates=get_o3lossclams_dates)
app.jinja_env.globals.update(get_vpsc_dates=get_vpsc_dates)

@babel.localeselector
def get_locale():
    """ToDo: if translation is completed, switch to en """
    return LANGUAGE_SELECTED or request.accept_languages.best_match(LANGUAGES.keys()) or 'de'


@app.route("/")
@app.route("/index")
def index():
    return render_template("/index.html",
                           eskp_info=_(u'About ESKP'),
                           )


@app.route('/ozoneloss/clams/2014')
def y2014():
    filename = os.path.join("templates", get_locale(), "rst", "ozoneloss_clams.rst")
    content = get_content(filename)
    return render_template("/ozoneloss_clams.html", act="ozoneloss/clams/2014", content=content, year=2014)

@app.route('/ozoneloss/clams/2013')
def y2013():
    filename = os.path.join("templates", get_locale(), "rst", "ozoneloss_clams.rst")
    content = get_content(filename)
    return render_template("/ozoneloss_clams.html", act="ozoneloss/clams/2013", content=content, year=2013)

@app.route('/ozoneloss/clams/2012')
def y2012():
    filename = os.path.join("templates", get_locale(), "rst", "ozoneloss_clams.rst")
    content = get_content(filename)
    return render_template("/ozoneloss_clams.html", act="ozoneloss/clams/2012", content=content, year=2012)

@app.route('/ozoneloss/clams/2011')
def y2011():
    filename = os.path.join("templates", get_locale(), "rst", "ozoneloss_clams.rst")
    content = get_content(filename)
    return render_template("/ozoneloss_clams.html", act="ozoneloss/clams/2011", content=content, year=2011)

@app.route('/ozoneloss/clams/2010')
def y2010():
    filename = os.path.join("templates", get_locale(), "rst", "ozoneloss_clams.rst")
    content = get_content(filename)
    return render_template("/ozoneloss_clams.html", act="ozoneloss/clams/2010", content=content, year=2010)

@app.route('/ozoneloss/vpsc/2014')
def y2014a():
    filename = os.path.join("templates", get_locale(), "rst", "ozoneloss_vpsc.rst")
    content = get_content(filename)
    filename = os.path.join("templates", get_locale(), "rst", "explanation_vpsc.rst")
    explanation = get_content(filename)

    return render_template("/ozoneloss_vpsc.html", act="ozoneloss/vpsc/2014", content=content, content_explanation=explanation, year=2014)

@app.route('/ozoneloss/vpsc/2013')
def y2013a():
    filename = os.path.join("templates", get_locale(), "rst", "ozoneloss_vpsc.rst")
    content = get_content(filename)
    filename = os.path.join("templates", get_locale(), "rst", "explanation_vpsc.rst")
    explanation = get_content(filename)

    return render_template("/ozoneloss_vpsc.html", act="ozoneloss/vpsc/2014", content=content, content_explanation=explanation, year=2013)

@app.route('/ozoneloss/vpsc/2012')
def y2012a():
    filename = os.path.join("templates", get_locale(), "rst", "ozoneloss_vpsc.rst")
    content = get_content(filename)
    filename = os.path.join("templates", get_locale(), "rst", "explanation_vpsc.rst")
    explanation = get_content(filename)

    return render_template("/ozoneloss_vpsc.html", act="ozoneloss/vpsc/2014", content=content, content_explanation=explanation, year=2012)

@app.route('/ozoneloss/vpsc/2011')
def y2011a():
    filename = os.path.join("templates", get_locale(), "rst", "ozoneloss_vpsc.rst")
    content = get_content(filename)
    filename = os.path.join("templates", get_locale(), "rst", "explanation_vpsc.rst")
    explanation = get_content(filename)

    return render_template("/ozoneloss_vpsc.html", act="ozoneloss/vpsc/2014", content=content, content_explanation=explanation, year=2011)

@app.route('/ozoneloss/vpsc/2010')
def y2010a():
    filename = os.path.join("templates", get_locale(), "rst", "ozoneloss_vpsc.rst")
    content = get_content(filename)
    filename = os.path.join("templates", get_locale(), "rst", "explanation_vpsc.rst")
    explanation = get_content(filename)

    return render_template("/ozoneloss_vpsc.html", act="ozoneloss/vpsc/2014", content=content, content_explanation=explanation, year=2011)

@app.route('/de')
def de():
    global LANGUAGE_SELECTED
    LANGUAGE_SELECTED = "de"
    saying, author = get_saying()
    return render_template("/index.html",
                           saying=saying,
                           author=author,
                           eskp_info=_(u'About ESKP'),
                           )

@app.route('/en')
def en():
    saying, author = get_saying()
    global LANGUAGE_SELECTED
    LANGUAGE_SELECTED = "en"
    return render_template("/index.html",
                           saying=saying,
                           author=author,
                           eskp_info=_(u'About ESKP'),
                           )

@app.route("/eskp")
def eskp():
    filename = os.path.join("templates", get_locale(), "rst", "eskp.rst")
    content = get_content(filename)
    return render_template("/content.html", act="eskp", content=content)

@app.route("/ozoneloss")
def task():
    filename = os.path.join("templates", get_locale(), "rst", "ozoneloss.rst")
    content = get_content(filename)
    return render_template("/ozoneloss.html", act="ozoneloss", content=content)

@app.route("/ozoneloss/clams")
def task1():
    filename = os.path.join("templates", get_locale(), "rst", "ozoneloss_clams.rst")
    content = get_content(filename)
    return render_template("/ozoneloss_clams.html", act="ozoneloss/clams", content=content)

@app.route("/ozoneloss/vpsc")
def task2():
    filename = os.path.join("templates", get_locale(), "rst", "ozoneloss_vpsc.rst")
    content = get_content(filename)
    return render_template("/ozoneloss_vpsc.html", act="ozoneloss/vpsc", content=content)

@app.route("/iek-7")
def submission():
    filename = os.path.join("templates", get_locale(), "rst", "iek-7.rst")
    content = get_content(filename)
    return render_template("/content.html", act="submission", content=content)


@app.route("/imprint")
def imprint():
    filename = os.path.join("templates", get_locale(), "rst", "imprint.rst")
    content = get_content(filename)
    return render_template("/content.html", act="imprint", content=content)



@app.errorhandler(404)
def page_not_found(e):
    msg = _(u"Url: %(url)s not found", url=request.url)
    info = _(u"This information is not available!")
    return render_template("404.html", msg=msg, info=info)

if __name__ == "__main__":
    app.run(host='localhost', port=5014, debug=True)
